@@ -261,6 +261,24 @@ class Client(object):
         req.raise_for_status()
         return req.json()
 
+    def list_online_events(self):
+        """List online events "salons en ligne".
+
+        Returns:
+            a list of dicts, see
+            https://www.emploi-store-dev.fr/portail-developpeur-cms/home/catalogue-des-api/documentation-des-api/api-evenements-pole-emploi-v1/rechercher-les-salons-en-ligne.html
+            for details of the fields.
+        """
+        scope = 'api_evenementsv1 evenements'
+        req = requests.get(
+            self.api_url + '/evenements/v1/salonsenligne',
+            headers={
+                'Accept': 'application/json',
+                'Authorization': 'Bearer %s' % self.access_token(scope),
+            })
+        req.raise_for_status()
+        return req.json()
+
 
 class Package(object):
     """A package of resources available.
